@@ -4,7 +4,11 @@ process_html_res <- function(html, reg, processor) {
   html <- one_string(html)
   process_img_src <- function(img_src) {
     src <- sub(reg, '\\1', img_src)
-    processor(img_src, src)
+    vapply(
+      seq_along(img_src),
+      function(i) processor(img_src[[i]], src[[i]]),
+      character(1)
+    )
   }
   html <- stringr::str_replace_all(html, reg, process_img_src)
   strsplit(html, "\n", fixed = TRUE)[[1]]
