@@ -278,6 +278,14 @@ pandoc_metadata_arg <- function(name,
   c("--metadata", if (missing(value)) name else paste(name, "=", value, sep = ""))
 }
 
+#' @rdname pandoc_args
+#' @param file string. Path to a file
+#' @export
+pandoc_metadata_file_arg <- function(file) {
+
+  c("--metadata-file", pandoc_path_arg(file))
+}
+
 
 #' @rdname pandoc_args
 #' @export
@@ -436,12 +444,12 @@ pandoc_template <- function(metadata, template, output, verbose = FALSE) {
 pandoc_self_contained_html <- function(input, output) {
 
   # make input file path absolute
-  input <- normalizePath(input)
+  input <- normalize_path(input)
 
   # ensure output file exists and make it's path absolute
   if (!file.exists(output))
     file.create(output)
-  output <- normalizePath(output)
+  output <- normalize_path(output)
 
   # create a simple body-only template
   template <- tempfile(fileext = ".html")
