@@ -840,6 +840,9 @@ render <- function(input,
 
     perf_timer_start("pre-processor")
 
+    if (has_dependencies(knit_meta, "output_format_dependency")) {
+        output_format <- merge_output_format_dependencies(output_format, knit_meta)
+    }
     # call any pre_processor
     if (!is.null(output_format$pre_processor)) {
       extra_args <- output_format$pre_processor(front_matter,
@@ -1200,7 +1203,11 @@ resolve_df_print <- function(df_print) {
 output_metadata = knitr:::new_defaults()
 
 file_scope_split <- function(input, fun) {
-  inputs <- fun(input)
+  inputs <- if (length(formals(fun)) == 1L) {
+    fun(input) # for the backward compatibility
+  } else {
+    fun(input, NULL) # the second argument implies current file scope
+  }
 
   # file_scope_fun should split the input file in several
   # do nothing if not and return input file unsplited
